Welcome to Vanilla's documentation!
===================================

Concepts
--------

.. toctree::
   :maxdepth: 1

   concepts/positioning


Objects
-------

Windows
^^^^^^^

.. toctree::
  :maxdepth: 1

  objects/Window
  objects/FloatingWindow
  objects/Sheet
  objects/Drawer

Layout Views
^^^^^^^^^^^^

.. toctree::
  :maxdepth: 1

  objects/Group
  objects/Tabs
  objects/ScrollView
  objects/SplitView
  objects/Box
  objects/Popover
  objects/HorizontalLine
  objects/VerticalLine
  objects/GridView
  objects/HorizontalStackView
  objects/VerticalStackView

Data Views
^^^^^^^^^^

.. toctree::
  :maxdepth: 1

  objects/List
  objects/List2
  objects/ImageView
  objects/LevelIndicator

Buttons
^^^^^^^

.. toctree::
  :maxdepth: 1

  objects/Button
  objects/SquareButton
  objects/ImageButton
  objects/GradientButton
  objects/HelpButton
  objects/SegmentedButton

Inputs
^^^^^^

.. toctree::
  :maxdepth: 1

  objects/TextEditor
  objects/TextBox
  objects/EditText
  objects/SecureEditText
  objects/DatePicker
  objects/SearchBox
  objects/CheckBox
  objects/ColorWell
  objects/ComboBox
  objects/PopUpButton
  objects/ActionButton
  objects/RadioGroup
  objects/Slider

Progress Indicators
^^^^^^^^^^^^^^^^^^^

.. toctree::
  :maxdepth: 1

  objects/ProgressBar
  objects/ProgressSpinner


Indices and tables
------------------

* :ref:`genindex`
